<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_HK" version="2.1">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>系統監視器</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>系統監視器是一個對硬件負載、程序運行和系統服務，進行監測查看和管理操作的系統工具。</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>隱藏詳情</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation>總體利用率</translation>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation>個體利用率</translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>讀取</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>寫入</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60秒</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1天%2小時%3分鐘</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>總利用率</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>當前頻率</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>頻率</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>製造商</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>插槽</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>邏輯處理器</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>虛擬化</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>L1緩存（指令）</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>L1緩存（數據）</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>L2緩存</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>L3緩存</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>平均負載</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>文件描述符數</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>進程數</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>線程數</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>主機名</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>類型</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>運行時間</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60秒</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>無搜索結果</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>詳細訊息</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>詳細訊息</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>已啟動</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>重載中</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>未啟動</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>已失敗</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>啟動中</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>停止中</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>佔位</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>未找到</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>無效設置</translation>
    </message>
    <message>
        <source>error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>已合併</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>已屏蔽</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>已加載</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>已啟用</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>已禁用</translation>
    </message>
    <message>
        <source>static</source>
        <translation>靜態</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>瞬態</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>間接</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>運行時啟用</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>已屏蔽</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>已生成</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>dead</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>預啟動</translation>
    </message>
    <message>
        <source>start</source>
        <translation>啟動中</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>start-post</translation>
    </message>
    <message>
        <source>running</source>
        <translation>正在運行</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>已退出</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>重載中</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>已停止</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>stop-watchdog</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>stop-sigterm</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>stop-sigkill</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>stop-post</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>final-sigterm</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>final-sigkill</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>已失敗</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>自動重啟</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>已使用</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>可用</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>共享內存</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>高速緩存</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>數據緩存</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>交換緩存區</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>活躍的緩衝文件</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>不活躍的緩衝文件</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>髒頁</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>映射大小</translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>交換空間大小</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>可用交換空間</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>內核數據結構緩存</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>型號</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>讀取速度</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>寫入速度</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>容量</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>讀扇區次數</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>每秒讀操作次數</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>每秒讀扇區次數</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>每秒合併讀操作次數</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>寫扇區次數</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>寫完成次數</translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>合併寫完成次數</translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>每秒寫操作次數</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>每秒寫扇區次數</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>每秒合併寫操作次數</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>確 定</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>系統</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>顯示快捷鍵</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>結束進程會有丟失數據的風險。
您確定要結束選中的進程嗎？</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>結束進程</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>強制結束進程會有丟失數據的風險。
您確定要結束選中的進程嗎？</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>強制結束應用會有丟失數據的風險。
您確定要結束選中的應用嗎？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>強制結束</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>結束進程</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation>設置</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>容量大小</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>IP位址：</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>子網掩碼：</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>廣播：</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>掩碼長度：</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>域：</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>連接類型</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>伺服器別號</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>信號質量</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>信號強度</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>底噪</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>速率</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>接收包數量</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>總計接收</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>接收（錯誤包）</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>接收（丟棄包）</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>接收FIFO</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>分組幀錯誤</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>發送包數量</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>總計發送</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>發送（錯誤包）</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>發送FIFO</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>載波損耗</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>發送（丟棄包）</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>命令行</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>啟動時間</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>進程名</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>點擊您想結束的應用程序</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>內存</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>接收</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>處理器</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>磁盤讀取</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>磁盤寫入</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>內存</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>交換空間</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>未啟用</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>正在接收</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>正在發送</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>網絡</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>總計接收</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>總計發送</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>發送</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>磁盤</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>非常高</translation>
    </message>
    <message>
        <source>High</source>
        <translation>高</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>普通</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>低</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>非常低</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>自定義</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>無效</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>進程號: %1, Error: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>改變進程優先級失敗</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>應用程序</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>我的進程</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>所有進程</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation>正在加載</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>暫停進程失敗</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>恢復進程失敗</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>強制結束進程失敗</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>未知錯誤</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>發送信號到進程失敗</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>結束進程失敗</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>（正在運行%1個應用程序和%2個系統進程）</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>無響應</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>托盤</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>查看命令所在位置</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>屬性</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>結束進程</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>繼續進程</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>強制結束進程</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>改變優先級</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>暫停進程</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>自定義優先級</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>更 改</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>處理器</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>內存</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>磁盤寫入</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>磁盤讀取</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>下載</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>上傳</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>進程號</translation>
    </message>
    <message>
        <source>User</source>
        <translation>用戶</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>優先級</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>共享內存</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>虛擬內存</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>不支持</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設置</translation>
    </message>
    <message>
        <source>System Protection</source>
        <translation>系統防護</translation>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>當數值高於以下閾值時自動報警</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>消息通知</translation>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation>CPU佔用 (%)</translation>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation>內存佔用 (%)</translation>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation>預警間隔 (分鐘)</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>服務的啟動方式設置失敗</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>錯誤：由於子進程崩潰，服務的啟動方式設置失敗</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>服務實例名</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>確 定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>刷新</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>啟動</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>重新啟動</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>設置啟動方式</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>內存加載</translation>
    </message>
    <message>
        <source>Start State</source>
        <translation>啟動狀態</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>運行狀態</translation>
    </message>
    <message>
        <source>Start Tactic</source>
        <translation>啟用策略</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>描述</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>進程號</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>啟動方式</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation>設置</translation>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation>（閾值可修改）</translation>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation>數值範圍：%1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>強制結束應用程序</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>舒展</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>緊湊</translation>
    </message>
    <message>
        <source>View</source>
        <translation>視圖</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>程序進程</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>系統服務</translation>
    </message>
</context>
</TS>
